@@ -1,13 +1,18 @@
 package Test::Webserver;
 
-use IO::Scalar;
-use Dancer qw/any get status params header/;
+use Dancer;
 use Daemon::Daemonize qw//;
 
 any [ 'get', 'put', 'post', 'delete' ] => '/code/:code' => sub {
     status int params->{code};
 };
 
+get '/sleep/:time' => sub {
+    my $time = int params->{time};
+    sleep $time;
+    status 204;
+};
+
 get '/redirect/:times' => sub {
     my $times = int params->{times};
     if ($times) {
@@ -27,7 +32,7 @@ sub start {
         run   => sub {
             Daemon::Daemonize->write_pidfile($pid);
             $SIG{TERM} = sub { Daemon::Daemonize->delete_pidfile($pid); exit };
-            Dancer->dance;
+            dance;
         }
     );
 }
